summaryrefslogtreecommitdiffstats
path: root/chrome/renderer/navigation_state.h
diff options
context:
space:
mode:
authordavemoore@chromium.org <davemoore@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-06-26 15:26:12 +0000
committerdavemoore@chromium.org <davemoore@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-06-26 15:26:12 +0000
commited42bc2f22755d2864056cb03fc2ef17793ba9f0 (patch)
tree6178994bc105ef269c37ab9155e951271cde19aa /chrome/renderer/navigation_state.h
parent6a914a59965413063517489060131b1627e6fdff (diff)
downloadchromium_src-ed42bc2f22755d2864056cb03fc2ef17793ba9f0.zip
chromium_src-ed42bc2f22755d2864056cb03fc2ef17793ba9f0.tar.gz
chromium_src-ed42bc2f22755d2864056cb03fc2ef17793ba9f0.tar.bz2
A recent change broke the load times. It also revealed some deficiencies.
This adds a new time marker for when a load is committed, which is a more interesting value than the start of the load (which we still keep). Also, the first layout time wasn't an interesting time to keep, instead we keep the time of the first paint. The histograms were modified to use the new values when appropriate. Review URL: http://codereview.chromium.org/147123 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@19361 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/renderer/navigation_state.h')
-rw-r--r--chrome/renderer/navigation_state.h21
1 files changed, 15 insertions, 6 deletions
diff --git a/chrome/renderer/navigation_state.h b/chrome/renderer/navigation_state.h
index 7d6aed5..46c17f3 100644
--- a/chrome/renderer/navigation_state.h
+++ b/chrome/renderer/navigation_state.h
@@ -54,7 +54,7 @@ class NavigationState : public WebKit::WebDataSource::ExtraData {
request_time_ = value;
}
// The time that this navigation actually started.
const base::Time& start_load_time() const {
return start_load_time_;
}
@@ -62,6 +62,14 @@ class NavigationState : public WebKit::WebDataSource::ExtraData {
start_load_time_ = value;
}
+ // The time that the document load was committed.
+ const base::Time& commit_load_time() const {
+ return commit_load_time_;
+ }
+ void set_commit_load_time(const base::Time& value) {
+ commit_load_time_ = value;
+ }
+
// The time that the document finished loading.
const base::Time& finish_document_load_time() const {
return finish_document_load_time_;
@@ -79,11 +87,11 @@ class NavigationState : public WebKit::WebDataSource::ExtraData {
}
// The time that layout first ran after a new navigation.
- const base::Time& first_layout_time() const {
- return first_layout_time_;
+ const base::Time& first_paint_time() const {
+ return first_paint_time_;
}
- void set_first_layout_time(const base::Time& value) {
- first_layout_time_ = value;
+ void set_first_paint_time(const base::Time& value) {
+ first_paint_time_ = value;
}
// True if we have already processed the "DidCommitLoad" event for this
@@ -123,9 +131,10 @@ class NavigationState : public WebKit::WebDataSource::ExtraData {
PageTransition::Type transition_type_;
base::Time request_time_;
base::Time start_load_time_;
+ base::Time commit_load_time_;
base::Time finish_document_load_time_;
base::Time finish_load_time_;
- base::Time first_layout_time_;
+ base::Time first_paint_time_;
bool request_committed_;
bool is_content_initiated_;
int32 pending_page_id_;
@@ -54,7 +54,7 @@ class NavigationState : public WebKit::WebDataSource::ExtraData {
request_time_ = value;
}
- // The time that this navigation actually started.
+ // The time that the document load started.
const base::Time& start_load_time() const {
return start_load_time_;